
const MOZILLA_CONTENT_PACK = "chrome://help/locale/firebirdhelp.rdf";

var helpFileURI = MOZILLA_CONTENT_PACK;

/**
 * Opens up the Mozilla Help Viewer with the content pack taken in and the topic
 * taken in. If the content is not provided, the default content pack (set through
 * setHelpFileUri()) is used.
 *
 *@param openHelp Opens up the Mozilla Help Viewer with this content pack.
 *@param topic The topic to launch the Mozilla Help Viewer with.
 */
function openHelp(topic, contentPack)
{
  helpFileURI = contentPack || helpFileURI;

  var topWindow = locateHelpWindow(helpFileURI);

  if ( topWindow ) {
    topWindow.focus();
    topWindow.displayTopic(topic);
  } else {
    const params = Components.classes["@mozilla.org/embedcomp/dialogparam;1"]
                             .createInstance(Components.interfaces.nsIDialogParamBlock);
    params.SetNumberStrings(2);
    params.SetString(0, helpFileURI);
    params.SetString(1, topic);
    const ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                         .getService(Components.interfaces.nsIWindowWatcher);
    ww.openWindow(null, "chrome://help/content/help.xul", "_blank", "chrome,all,alwaysRaised,dialog=no", params);
  }
}

/**
 * Sets the default content pack to use in the openHelp() function.
 *
 *@param rdfURI The URI to the default content pack.
 */
function setHelpFileURI(rdfURI)
{
  helpFileURI = rdfURI;
}

/**
 *Locates an existing help window open for this content pack.
 *
 *@param contentPack The URI to the content pack to see if a open help window uses.
 */
function locateHelpWindow(contentPack) {
    const windowManagerInterface = Components
        .classes['@mozilla.org/appshell/window-mediator;1'].getService()
        .QueryInterface(Components.interfaces.nsIWindowMediator);
    const iterator = windowManagerInterface.getEnumerator("mozilla:help");
    var topWindow = null;
    var aWindow;

    while (iterator.hasMoreElements()) {
        aWindow = iterator.getNext();
        if (aWindow.getHelpFileURI() == contentPack) {
            topWindow = aWindow;
        }
    }
    return topWindow;
}
